#!/bin/bash
############################################################################
# 0DaysDateFix v1.2.1 by Turranius                                         #
####                                                                    ####
# This little script will change the date on any dated dirs, be it 0days   #
# or Mp3 folders. The only requirement is that the dirs in in the format   #
# "MonthDay", like 0628.                                                   #
# It can also rename said folders to DDMMYY is you have a large archive.   #
####                                                                    ####
# Installation:                                                            #
# Put this script in /glftpd/bin, or wherever you like really.             #
# Make it executable ( chmod 755 0daysdatefix.sh )                         #
# Edit the settings below:                                                 #
# DATEDDIRS can be any number of folders containing dated dirs, space      #
# separated. The current strucure is one per line, start and end with ".   #
#                                                                          #
# To rename folders from mmdd to mmddyy, add a ~ after its path.           #
# This is for archives more then a year old. It will check the year of the #
# folder so make sure any dirs from, say 01, really dosnt have a date of   #
# 02. This might not work on all distros. Search for year= and change it   #
# if it does not. I cant say how its supposed to be on your distro though. #
# Only tested on RedHat and Mandrake.                                      #
# It will make a check to see that the dir is really 4 chars long first,   #
# otherwise it will not be renamed.                                        #
#                                                                          #
# Any folders contained in these dated dirs can be excluded in EXCLUDE.    #
# Separate the excludes with a |                                           #
# Crontab it or just run it manually as often or seldom as you like.       #
# To run it 15 minutes past midnight, each day, do:                        #
# 15 0 * * * /glftpd/bin/0daysdatefix.sh                                   #
#                                                                          #
# At the bottom is a setting called REDHAT8. To see if you should be using #
# this one, do the following. CD to one of your dated dirs. Say you have   #
# one folder in here that is called 0925. Now do the following.            #
# ls --full-time | grep -w 0925 | awk '{print $10}' | cut -b3-4            #
# If that returns the 2 last digits of this year, you should NOT set this  #
# to true. If it was empty, try changing the $10 to $6. See if this helps. #
# If it does, you should set this one TRUE.                                #
#                                                                          # 
# If you wish to see whats happening when its running, start it with the   #
# variable 'display' (0daysdatefix.sh display).                            #
####                                                                    ####
# Changelog:                                                               #
# 1.2.1 : Added option REDHAT8. I noticed the full time argument being     #
#         different on RH8, so added an option for it. I suspect it is the #
#         same with different distros, ala slackware etc.                  #
#         If it throws out a lot of touch errors or "Cant move folder into #
#         itself", try flipping this option.                               #
#                                                                          #
#         Fixed it so that once it renames a folder, it will still keep    #
#         the time on it up to date, but then it will go by the name of    #
#         the folder instead of trying to check creation date like it does #
#         when renaming from 4 to 6 chars.                                 #
#         Previously, once it renamed a folder to 6 digits, it stopped     #
#         updated the time on it.                                          #
#                                                                          #
#         Added more output when running it with the argument 'display'.   #
#                                                                          #
# 1.2   : Added option to rename dated folders from mmdd to mmddyy.        #
#         Only enable this in archive dirs.                                #
# 1.1.1 : Fixed it where it would not run the first 9 days of the month.   #
# 1.1 : Handles an infinite amount of dated dirs.                          #
#       Excludes are working.                                              #
#       Better (?) documented, hehe.                                       #
# 1.0 : Initial release. Only handles one dir.                             #
############################################################################
# Contact Turranius on efnet (turranius/turran/turr|away/turr|work).       #
############################################################################

DATEDDIRS="
/glftpd/site/0DAYS
/glftpd/site/Archive/0DAYS/0DAYS1~
"
# Space separeted

EXCLUDE='lost\+found|journ|GROUPS|!Today|!Yesterday' # | separated
REDHAT8="FALSE" # See instuctions above.

############################################################
## No changes below needed                                 #
############################################################

today="$(date +%m%d)"

for dir in $DATEDDIRS; do
  rename="$( echo $dir | grep "~" )"
  if [ "$rename" != "" ]; then
    dir="$( echo $dir | awk -F"~" '{print $1}' )"
    renameit="yes"
  else
    renameit="no"
  fi

  cd $dir

  for i in `ls -f -A | egrep -v $EXCLUDE`; do
    if [ "$i" != "$today" ]; then 
      if [ "$1" = "display" ]; then
        echo "Checking: $dir/$i"
      fi
      if [ "$renameit" = "yes" ]; then
        if [ "$REDHAT8" != "TRUE" ]; then
          year="$( ls --full-time $dir | grep -w $i | awk '{print $10}' | cut -b3-4 )"
        else
          year="$( ls --full-time $dir | grep -w $i | awk '{print $6}' | cut -b3-4 )"
        fi
        lenght="$( echo $i | wc -L | tr -d ' ' )"
        if [ "$lenght" = "4" ]; then
          if [ "$1" = "display" ]; then
            echo " mv -f $i $i$year"
          fi
          mv -f $i $i$year
          folder="$i$year"
          if [ "$1" = "display" ]; then
            echo " touch $folder -t $year$i"0000""
          fi
          touch $folder -t $year$i"0000"
        fi
        if [ "$lenght" = "6" ]; then
          datef="$( echo $i | cut -b1-4 )"
          year="$( echo $i | cut -b5-6 )"
          if [ "$year" -gt "50" ]; then
            yearf="19"$year
          else
            yearf="20"$year
          fi
          if [ "$1" = "display" ]; then
            echo " touch $i -t $yearf$datef"0000""
          fi
          touch $i -t $yearf$datef"0000"
        fi
      else
        if [ "$1" = "display" ]; then
          echo " touch $i -t $i"0000""
        fi
        touch $i -t $i"0000"
      fi
    else
      if [ "$1" = "display" ]; then
        echo "Not touching todays dir: $dir/$i"
      fi
    fi
  done
done

exit 0
